@@ -35,13 +35,15 @@ class AbstractAddress(models.Model):
     line4 = models.CharField(_("City"), max_length=255, blank=True, null=True)
     state = models.CharField(_("State/County"), max_length=255, blank=True, null=True)
     postcode = models.CharField(_("Post/Zip-code"), max_length=64)
-    country = models.ForeignKey('address.Country')
+    country = models.ForeignKey('address.Country', verbose_name=_("Country"))
     
     # A field only used for searching addresses - this contains all the relevant fields
     search_text = models.CharField(_("Search text"), max_length=1000)
     
     class Meta:
         abstract = True
+        verbose_name = _('Address')
+        verbose_name_plural = _('Addresses')
 
     def save(self, *args, **kwargs):
         self._clean_fields()
@@ -141,22 +143,23 @@ class AbstractCountry(models.Model):
         
 
 class AbstractShippingAddress(AbstractAddress):
-    u"""
+    """
     Shipping address.
     
     A shipping address should not be edited once the order has been placed - 
     it should be read-only after that. 
     """
-    phone_number = models.CharField(max_length=32, blank=True, null=True)
+    phone_number = models.CharField(_("Phone number"), max_length=32, blank=True, null=True)
     notes = models.TextField(blank=True, null=True,
-                             verbose_name='Courier instructions',
-                             help_text="For example, leave the parcel in the wheelie bin " \
-                                       "if I'm not in.")
+                             verbose_name=_('Courier instructions'),
+                             help_text=_("For example, leave the parcel in the wheelie bin " \
+                                       "if I'm not in."))
     
     class Meta:
         abstract = True
-        verbose_name_plural = "shipping addresses"
-        
+        verbose_name = _("Shipping address")
+        verbose_name_plural = _("Shipping addresses")
+
     @property    
     def order(self):
         """
@@ -227,7 +230,8 @@ class AbstractUserAddress(AbstractShippingAddress):
     
     class Meta:
         abstract = True
-        verbose_name_plural = "User addresses"
+        verbose_name = _("User address")
+        verbose_name_plural = _("User addresses")
         ordering = ['-num_orders']
 
 
@@ -235,8 +239,9 @@ class AbstractBillingAddress(AbstractAddress):
     
     class Meta:
         abstract = True
-        verbose_name_plural = "Billing addresses"   
-        
+        verbose_name_plural = _("Billing address")
+        verbose_name_plural = _("Billing addresses")
+
     @property    
     def order(self):
         """
