@@ -1,6 +1,7 @@
 from django.http import HttpResponseRedirect
 from django.contrib import messages
 from django.core.urlresolvers import reverse
+from django.utils.translation import ugettext_lazy as _
 
 from oscar.core.loading import get_class
 ProgressChecker = get_class('checkout.utils', 'ProgressChecker')
@@ -17,7 +18,7 @@ def prev_steps_must_be_complete(view_fn):
     def _view_wrapper(self, request, *args, **kwargs):
         checker = ProgressChecker()
         if not checker.are_previous_steps_complete(request):
-            messages.error(request, "You must complete this step of the checkout first")
+            messages.error(request, _("You must complete this step of the checkout first"))
             url_name = checker.get_next_step(request)
             return HttpResponseRedirect(reverse(url_name))
         return view_fn(self, request, *args, **kwargs)
@@ -31,7 +32,7 @@ def basket_required(view_fn):
     """
     def _view_wrapper(self, request, *args, **kwargs):
         if request.basket.is_empty and not 'checkout_basket_id' in request.session:
-            messages.error(request, "You must add some products to your basket before checking out")
+            messages.error(request, _("You must add some products to your basket before checking out"))
             return HttpResponseRedirect(reverse('oscar-basket'))
         return view_fn(self, request, *args, **kwargs)
     return _view_wrapper
