@@ -1,13 +1,15 @@
-from django.conf.urls.defaults import patterns, url
+from django.conf.urls import patterns, url
 from django.contrib.admin.views.decorators import staff_member_required
+from django.utils.translation import ugettext_lazy as _
 
 from oscar.core.application import Application
 from oscar.apps.dashboard.catalogue import views
 from oscar.apps.dashboard.nav import register, Node
 
-node = Node('Catalogue')
-node.add_child(Node('Products', 'dashboard:catalogue-product-list'))
-node.add_child(Node('Stock alerts', 'dashboard:stock-alert-list'))
+node = Node(_('Catalogue'))
+node.add_child(Node(_('Products'), 'dashboard:catalogue-product-list'))
+node.add_child(Node(_('Categories'), 'dashboard:catalogue-category-list'))
+node.add_child(Node(_('Stock alerts'), 'dashboard:stock-alert-list'))
 register(node, 10)
 
 
@@ -18,6 +20,12 @@ class CatalogueApplication(Application):
     product_create_redirect_view = views.ProductCreateRedirectView
     product_create_view = views.ProductCreateView
     product_update_view = views.ProductUpdateView
+    
+    category_list_view = views.CategoryListView
+    category_detail_list_view = views.CategoryDetailListView
+    category_create_view = views.CategoryCreateView
+    category_update_view = views.CategoryUpdateView
+    category_delete_view = views.CategoryDeleteView
 
     stock_alert_view = views.StockAlertListView
 
@@ -33,6 +41,16 @@ class CatalogueApplication(Application):
                 name='catalogue-product-list'),
             url(r'^stock-alerts/$', self.stock_alert_view.as_view(),
                 name='stock-alert-list'),
+            url(r'^categories/$', self.category_list_view.as_view(),
+                name='catalogue-category-list'),
+            url(r'^categories/(?P<pk>\d+)/$', self.category_detail_list_view.as_view(),
+                name='catalogue-category-detail-list'),
+            url(r'^categories/create/$', self.category_create_view.as_view(),
+                name='catalogue-category-create'),
+            url(r'^categories/update/(?P<pk>\d+)/$', self.category_update_view.as_view(),
+                name='catalogue-category-update'),
+            url(r'^categories/delete/(?P<pk>\d+)/$', self.category_delete_view.as_view(),
+                name='catalogue-category-delete'),
         )
         return self.post_process_urls(urlpatterns)
 
