@@ -1,6 +1,7 @@
 from django import forms
 
 from django.db.models.loading import get_model
+from django.utils.translation import ugettext_lazy as _
 
 ConditionalOffer = get_model('offer', 'ConditionalOffer')
 Condition = get_model('offer', 'Condition')
@@ -8,8 +9,10 @@ Benefit = get_model('offer', 'Benefit')
 
 
 class MetaDataForm(forms.ModelForm):
-    start_date = forms.DateField(widget=forms.DateInput(format='%Y-%m-%d'))
-    end_date = forms.DateField(widget=forms.DateInput(format='%Y-%m-%d'))
+    start_date = forms.DateField(widget=forms.DateInput(format='%Y-%m-%d'),
+                                 label=_("Start date"))
+    end_date = forms.DateField(widget=forms.DateInput(format='%Y-%m-%d'),
+                               label=_("End date"))
 
     class Meta:
         model = ConditionalOffer
@@ -33,5 +36,5 @@ class PreviewForm(forms.Form):
 
 
 class OfferSearchForm(forms.Form):
-    name = forms.CharField(required=False, label="Offer name")
-    is_active = forms.BooleanField(required=False)
+    name = forms.CharField(required=False, label=_("Offer name"))
+    is_active = forms.BooleanField(required=False, label=_("Is active?"))
