@@ -1,11 +1,12 @@
-from django.conf.urls.defaults import patterns, url
+from django.conf.urls import patterns, url
 from django.contrib.admin.views.decorators import staff_member_required
+from django.utils.translation import ugettext_lazy as _
 
 from oscar.core.application import Application
 from oscar.apps.dashboard.reports import views
 from oscar.apps.dashboard.nav import register, Node
 
-node = Node('Reports', 'dashboard:reports-index')
+node = Node(_('Reports'), 'dashboard:reports-index')
 register(node, 90)
 
 
