@@ -4,6 +4,7 @@ import re
 
 from django import forms
 from django.db.models import get_model
+from django.utils.translation import ugettext_lazy as _
 
 from oscar.core.loading import get_class
 
@@ -64,15 +65,15 @@ class BankcardNumberField(forms.CharField):
         """Check if given CC number is valid and one of the
            card types we accept"""
         non_decimal = re.compile(r'\D+')
-        value = non_decimal.sub('', value.strip())    
-           
+        value = non_decimal.sub('', value.strip())
+
         if value and not luhn(value):
-            raise forms.ValidationError("Please enter a valid credit card number.")
+            raise forms.ValidationError(_("Please enter a valid credit card number."))
         return super(BankcardNumberField, self).clean(value)
 
 
 class BankcardMonthWidget(forms.MultiWidget):
-    """ 
+    """
     Widget containing two select boxes for selecting the month and year
     """
     def decompress(self, value):
@@ -88,18 +89,17 @@ class BankcardMonthField(forms.MultiValueField):
     A modified version of the snippet: http://djangosnippets.org/snippets/907/
     """
     default_error_messages = {
-        'invalid_month': u'Enter a valid month.',
-        'invalid_year': u'Enter a valid year.',
+        'invalid_month': _('Enter a valid month.'),
+        'invalid_year': _('Enter a valid year.'),
     }
     num_years = 5
 
     def __init__(self, *args, **kwargs):
-        
         # Allow the number of years to be specified
         if 'num_years' in kwargs:
             self.num_years = kwargs['num_years']
             del kwargs['num_years']
-        
+
         errors = self.default_error_messages.copy()
         if 'error_messages' in kwargs:
             errors.update(kwargs['error_messages'])
@@ -109,13 +109,13 @@ class BankcardMonthField(forms.MultiValueField):
             forms.ChoiceField(choices=self.year_choices(),
                 error_messages={'invalid': errors['invalid_year']}),
         )
-        
+
         super(BankcardMonthField, self).__init__(fields, *args, **kwargs)
         self.widget = BankcardMonthWidget(widgets = [fields[0].widget, fields[1].widget])
-        
+
     def month_choices(self):
         return []
-    
+
     def year_choices(self):
         return []
 
@@ -133,7 +133,7 @@ class BankcardExpiryMonthField(BankcardMonthField):
     def clean(self, value):
         expiry_date = super(BankcardExpiryMonthField, self).clean(value)
         if date.today() > expiry_date:
-            raise forms.ValidationError("The expiration date you entered is in the past.")
+            raise forms.ValidationError(_("The expiration date you entered is in the past."))
         return expiry_date
 
     def compress(self, data_list):
@@ -149,8 +149,8 @@ class BankcardExpiryMonthField(BankcardMonthField):
             # find last day of the month
             day = monthrange(year, month)[1]
             return date(year, month, day)
-        return None 
-    
+        return None
+
 
 class BankcardStartingMonthField(BankcardMonthField):
     """
@@ -169,7 +169,7 @@ class BankcardStartingMonthField(BankcardMonthField):
     def clean(self, value):
         starting_date = super(BankcardMonthField, self).clean(value)
         if starting_date and date.today() < starting_date:
-            raise forms.ValidationError("The starting date you entered is in the future.")
+            raise forms.ValidationError(_("The starting date you entered is in the future."))
         return starting_date
 
     def compress(self, data_list):
@@ -183,23 +183,23 @@ class BankcardStartingMonthField(BankcardMonthField):
             year = int(data_list[1])
             month = int(data_list[0])
             return date(year, month, 1)
-        return None 
-    
+        return None
+
 
 class BankcardForm(forms.ModelForm):
-    
-    number = BankcardNumberField(max_length=20, widget=forms.TextInput(attrs={'autocomplete':'off'}), label="Card number")
-    name = forms.CharField(max_length=128, label="Name on card")
-    cvv_number = forms.RegexField(required=True, label="CVV Number",
+    number = BankcardNumberField(max_length=20, widget=forms.TextInput(attrs={'autocomplete':'off'}),
+                                 label=_("Card number"))
+    name = forms.CharField(max_length=128, label=_("Name on card"))
+    cvv_number = forms.RegexField(required=True, label=_("CVV Number"),
                                   regex=r'^\d{3,4}$', widget=forms.TextInput(attrs={'size': '5'}))
-    start_month = BankcardStartingMonthField(label="Valid from", required=False)
-    expiry_month = BankcardExpiryMonthField(required=True, label = "Valid to")
-    
+    start_month = BankcardStartingMonthField(label=_("Valid from"), required=False)
+    expiry_month = BankcardExpiryMonthField(required=True, label=_("Valid to"))
+
     class Meta:
         model = BankcardModel
         exclude = ('user', 'partner_reference')
         fields = ('number', 'name', 'start_month', 'expiry_month', 'cvv_number')
-        
+
     def get_bankcard_obj(self):
         """
         Returns a Bankcard object for use in payment processing.
@@ -213,17 +213,17 @@ class BankcardForm(forms.ModelForm):
         if self.cleaned_data['start_month']:
             kwargs['start_date'] = self.cleaned_data['start_month'].strftime("%m/%y")
         return Bankcard(**kwargs)
-    
+
 
 class BillingAddressForm(forms.ModelForm):
-    
+
     def __init__(self, *args, **kwargs):
         super(BillingAddressForm,self ).__init__(*args, **kwargs)
-        self.set_country_queryset() 
-        
+        self.set_country_queryset()
+
     def set_country_queryset(self):
         self.fields['country'].queryset = Country._default_manager.all()
-    
+
     class Meta:
         model = BillingAddress
         exclude = ('search_text',)
\ No newline at end of file
